==> datanucleus-api-jpa-4.1.14-sources.jar: org/datanucleus/api/jpa/annotations/Extension.java <==
/**********************************************************************
Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.api.jpa.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * DataNucleus Extension to JPA.
 */
@Target({ElementType.TYPE, ElementType.FIELD, ElementType.METHOD}) @Retention(RetentionPolicy.RUNTIME)
public @interface Extension
{
    /**
     * Vendor that the extension applies to. Provided for compatibility with JDO. 
     * @return The name of the vendor (DataNucleus).
     */
    String vendorName() default "datanucleus";

    /** 
     * The key for the extension.
     * @return The extension key
     */
    String key();

    /**
     * The value for the extension. 
     * @return Value for the extension
     */
    String value();
}

==> datanucleus-api-jpa-6.0.1-sources.jar: org/datanucleus/api/jpa/annotations/Extension.java <==
/**********************************************************************
Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.api.jpa.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Repeatable;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * DataNucleus Extension to JPA.
 */
@Target({ElementType.TYPE, ElementType.FIELD, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
@Repeatable(Extensions.class)
public @interface Extension
{
    /**
     * Vendor that the extension applies to. Provided for compatibility with JDO. 
     * @return The name of the vendor (DataNucleus).
     */
    String vendorName() default "datanucleus";

    /** 
     * The key for the extension.
     * @return The extension key
     */
    String key();

    /**
     * The value for the extension. 
     * @return Value for the extension
     */
    String value();
}
